/* $Id: xpci_adapter.h,v 1.1 2004/03/04 23:04:03 moleres Exp $ */
/******************************************************************************
*
*       XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
*       AS A COURTESY TO YOU, SOLELY FOR USE IN DEVELOPING PROGRAMS AND
*       SOLUTIONS FOR XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE,
*       OR INFORMATION AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE,
*       APPLICATION OR STANDARD, XILINX IS MAKING NO REPRESENTATION
*       THAT THIS IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
*       AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
*       FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
*       WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
*       IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
*       REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
*       INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
*       FOR A PARTICULAR PURPOSE.
*
*       (c) Copyright 2004 Xilinx Inc.
*       All rights reserved.
*
******************************************************************************/
/*****************************************************************************/
/**
*
* @file xpci_adapter.h
*
* The Xilinx XPci Adapter component.  This component interfaces between the
* XPci driver, the WindRiver VxWorks operating system, and the BSP. The
* externally visible functions listed in this header file are typically called
* from the BSP.  The XPciAdapter_Init() function initializes the Xilinx device
* driver, making it available for use by an application or the BSP.
*
* Note that the standard VxWorks PCI driver is sufficient to communicate through
* PCI memory space.  The VxWorks PCI driver is used in the BSP sysBusPci.c file
* to initialize the Xilinx PCI device. The purpose of this adapter is to
* initialize and provide access to the Xilinx device driver. The Xilinx device
* driver allows the application to primarily discover and handle errors that
* are available in the Xilinx PCI device.
*
* <b>PCI Configuration</b>
*
* Minimal configuration of the PCI header is done in the BSP (as produced by
* the EDK) and no additional configuration is done by this adapter.  The BSP
* configures the PCI host bridge (the Xilinx PCI device) to be enable memory
* access and bus mastering. It is the user's responsibility to add any
* additional PCI device configuration to the BSP or to configure the PCI
* headers as part of the user application.
*
* <b>PCI Interrupts</b>
*
* The Xilinx PCI device is a single function device that can generate an INTR_A
* output.  This interrupt is coalesced on the PCI interrupt lines with the
* INTR_A outputs of other PCI devices. Also, the system may contain PCI devices
* that also generate INTR_B/C/D outputs, and the system designer can hook these
* interrupt outputs into the system interrupt controller by any means desired.
*
* VxWorks and the Tornado BSP provide a mechanism (see the pciIntLib library
* regarding shared PCI interrupts) by which a user can register interrupt
* handlers for the various PCI interrupts. This Xilinx XPci adapter does not
* handle interrupts in any way. It is the responsibility of the application
* developer to appropriately register handlers and manage PCI interrupts. The
* application developer may make use of the XPci device driver and its existing
* interrupt handler if necessary.
*
* <pre>
* MODIFICATION HISTORY:
*
* Ver   Who  Date     Changes
* ----- ---- -------- -----------------------------------------------
* 1.00a rpm  02/27/04 First release
* </pre>
*
*****************************************************************************/

#ifndef XPCI_ADAPTER_H /* prevent circular inclusions */
#define XPCI_ADAPTER_H /* by using protection macros */

/***************************** Include Files ********************************/

#include "xpci.h"

/************************** Constant Definitions ****************************/


/**************************** Type Definitions ******************************/


/***************** Macros (Inline Functions) Definitions ********************/


/************************** Function Prototypes *****************************/

/*
 * The functions visible to the RTOS or the BSP.
 */
XStatus XPciAdapter_Init(int DeviceId, int BusNo, int SubBusNo);
XPci *XPciAdapter_GetDriver(int DeviceId);


#endif            /* end of protection macro */
